@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.91 2005/05/16 16:15:22 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.102 2006/01/17 02:16:11 tkaroonb Exp $
  *
- *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -108,7 +108,7 @@ Vars v;            /* Calctool variables and options. */
  *           |  a b c d e f g h i j k l m n o p q r s t u v w x y z
  *-----------+-----------------------------------------------------
  *  Lower:   |  a b c d e f     i     l m n   p   r s t u v   x
- *  Upper:   |  A   C D E F G     J K L   N   P   R S T       X Y
+ *  Upper:   |  A   C D E F G     J K L M N   P   R S T       X Y
  *  Numeric: |  0 1 2 3 4 5 6 7 8 9
  *  Other:   |  @ . + - * / = % ( ) # < > [ ] { } | & ~ ^ ? ! :
  *           |  BackSpace Delete Return
@@ -166,8 +166,9 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     NULL,
     number
 },
-{    
-    N_("/"),
+{
+    /* Note to translators: this is a division sign (÷) */
+    N_("\303\267"),
     N_("Divide"),
     NULL,
     { 0,         GDK_SHIFT_MASK, 0,             0,      GDK_SHIFT_MASK, 0 },
@@ -265,7 +266,8 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     number
 },
 {
-    N_("*"),
+    /* Note to translators: this is a multiplication sign (*) */
+    N_("\303\227"),
     N_("Multiply"),
     NULL,
     { GDK_SHIFT_MASK, 0,               0,     0,      0 },
@@ -289,7 +291,8 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     parenthesis
 },
 {
-    N_("+/-"),
+    /* Note to translators: this is a plus-minus sign (+/-) */
+    N_("\302\261"),
     N_("Change sign [c]"),
     NULL,
     { 0,     0 },
@@ -363,7 +366,8 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     number
 },
 {
-    N_("-"),
+    /* Note to translators: this is a minus sign (-) */
+    N_("\342\210\222"),
     N_("Subtract"),
     NULL,
     { 0,         0,               0,      0 },
@@ -382,12 +386,13 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     { GDK_percent, 0 },
     '%',
     M_NONE,
-    do_immed,  
+    do_calc,  
     NULL,
     immediate
 },
 {
-    N_("Sqrt"),
+    /* Note to translators: this is a square root sign */
+    N_("\342\210\232"),
     N_("Square root [s]"),
     NULL,
     { 0, 0 },   
@@ -446,7 +451,7 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     M_NONE,
     do_point,
     NULL,
-    number
+    number | dpoint
 },
 {
     N_("="),
@@ -819,16 +824,16 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     none
 },
 {
-    "    ",
-    "    ",
+    N_("Mod"),
+    N_("Modulus Division"),
     NULL,
-    { 0, 0 },
-    { 0, 0 },
-    ' ',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_M,          0 },
+    'M',
     M_NONE,
-    do_none,
-    NULL,
-    none
+    do_calc,
+    N_(" Mod "),
+    binop
 },
 {
     N_("Acc"),
@@ -877,7 +882,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     'e',
     M_NONE,
     do_expno,
-    N_("*10^"),
+    N_("e"),
     expnum
 },
 {
@@ -952,7 +957,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("E"),
@@ -964,7 +969,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("F"),
@@ -976,7 +981,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("Cos"),
@@ -1050,7 +1055,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("B"),
@@ -1061,7 +1066,8 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     'B',
     M_NONE,
     do_number,
-    NULL
+    NULL,
+    number
 },    
 {     
     N_("C"),
@@ -1073,7 +1079,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("Or"),
@@ -1144,8 +1150,6 @@ do_calctool(int argc, char **argv)
     char *ptr, title[MAXLINE];
     int i;
 
-    build_word_map();          /* Initialize i18n. */
-
     init_buttons();            /* Setup the buttons for "Basic" mode. */
 
     v->progname = argv[0];     /* Save programs name. */
@@ -1193,6 +1197,7 @@ do_calctool(int argc, char **argv)
     v->hyperbolic = 0;         /* Normal trig functions initially. */
     v->inverse    = 0;         /* No inverse functions initially. */
     v->down       = 0;         /* No mouse presses initially. */
+    v->warn_change_mode = 1;   /* Warn user when changing modes. */
 
     srand48((long) time((time_t *) 0));   /* Seed random number generator. */
 
